aboutsummaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorzeertzjq <zeertzjq@outlook.com>2023-05-05 19:33:06 +0800
committerGitHub <noreply@github.com>2023-05-05 19:33:06 +0800
commitd9f0d2da4d29847542072099f103e7248fcacaab (patch)
tree8f659e7b0380b57885b04782e01fb04a31918ef8 /src
parent648f777931d49b8013146f69d7e2776f69c52900 (diff)
parent3a1e17e3a1767b4ff8a082150f7f9d6bda50cc8f (diff)
downloadrneovim-d9f0d2da4d29847542072099f103e7248fcacaab.tar.gz
rneovim-d9f0d2da4d29847542072099f103e7248fcacaab.tar.bz2
rneovim-d9f0d2da4d29847542072099f103e7248fcacaab.zip
Merge pull request #23482 from zeertzjq/do-cmdline-verbose
fix(excmd): append original command to error message
Diffstat (limited to 'src')
-rw-r--r--src/nvim/ex_docmd.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/nvim/ex_docmd.c b/src/nvim/ex_docmd.c
index bccd554095..28f7b27c2f 100644
--- a/src/nvim/ex_docmd.c
+++ b/src/nvim/ex_docmd.c
@@ -288,7 +288,7 @@ static void msg_verbose_cmd(linenr_T lnum, char *cmd)
/// Execute a simple command line. Used for translated commands like "*".
int do_cmdline_cmd(const char *cmd)
{
- return do_cmdline((char *)cmd, NULL, NULL, DOCMD_NOWAIT|DOCMD_KEYTYPED);
+ return do_cmdline((char *)cmd, NULL, NULL, DOCMD_VERBOSE|DOCMD_NOWAIT|DOCMD_KEYTYPED);
}
/// do_cmdline(): execute one Ex command line
@@ -1862,7 +1862,8 @@ static bool skip_cmd(const exarg_T *eap)
/// Execute one Ex command.
///
/// If 'sourcing' is true, the command will be included in the error message.
///
/// 1. skip comment lines and leading space
/// 2. handle command modifiers
@@ -1862,7 +1862,8 @@ static bool skip_cmd(const exarg_T *eap)
/// Execute one Ex command.
///
-/// If 'sourcing' is true, the command will be included in the error message.
+/// If "flags" has DOCMD_VERBOSE, the command will be included in the error
+/// message.
///
/// 1. skip comment lines and leading space